import Mocha from 'mocha';
import { testSuiteCreate } from './create.spec.js';
import { testSuiteFind } from './find.spec.js';
import { testSuiteFindOne } from './findOne.spec.js';
import { testSuiteFindOneOrFail } from './findOneOrFail.spec.js';
import { testSuiteFormat } from './format.spec.js';
import { testSuiteRemove } from './remove.spec.js';
import { testSuiteSave } from './save.spec.js';
import { testSuiteWrite } from './write.spec.js';
/**
 * An abstract class for a repository.
 * @typeParam K - Keys of the EntityData
 * @typeParam R - Type of the Repository
 */
export class AbstractRepositoryTestSuite {
    constructor(AppDataSource) {
        this.AppDataSource = AppDataSource;
    }
    async initialize() {
        this.entityData = await this.getEntityData();
        this.repositoryTestData = {
            entityData: this.entityData,
            repository: this.repository,
            compareModels: this.compareModels.bind(this),
            compareFormatted: this.compareFormatted.bind(this),
            getFindOptionsWhere: this.getFindOptionsWhere.bind(this),
            validateCreate: this.validateCreate.bind(this),
            validateFormat: this.validateFormat.bind(this),
            validateWrite: this.validateWrite.bind(this),
            RepositoryClass: this.RepositoryClass,
        };
        this.testSuites = {
            additional: (() => {
                const testSuite = new Mocha.Suite('additional');
                return testSuite;
            })(),
            create: testSuiteCreate(this.repositoryTestData),
            find: testSuiteFind(this.repositoryTestData),
            findOne: testSuiteFindOne(this.repositoryTestData),
            findOneOrFail: testSuiteFindOneOrFail(this.repositoryTestData),
            format: testSuiteFormat(this.repositoryTestData),
            remove: testSuiteRemove(this.repositoryTestData),
            save: testSuiteSave(this.repositoryTestData),
            write: testSuiteWrite(this.repositoryTestData),
        };
    }
    addTestToSuite(suiteName, test) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        this.testSuites[suiteName].addTest(test(this.repositoryTestData));
    }
    addSuiteToSuite(suiteName, suite) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        this.testSuites[suiteName].addSuite(suite(this.repositoryTestData));
    }
    addSuite(suiteName, suite) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        this.testSuites[suiteName] = suite(this.repositoryTestData);
    }
    removeSuite(suiteName) {
        if (!this.testSuites || !this.repositoryTestData)
            throw new Error('Test suite has not been initialized');
        delete this.testSuites[suiteName];
    }
    async resetDatabase() {
        if (this.AppDataSource.connected) {
            await this.AppDataSource.teardown();
        }
        const newEntityData = await this.getEntityData();
        for (const key in newEntityData) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            this.entityData[key] = newEntityData[key];
        }
    }
    execute() {
        const testSuites = this.testSuites;
        const testSuite = new Mocha.Suite(`${this.repository.name} Repository Test`);
        for (const suite in testSuites) {
            const boundResetDatabase = this.resetDatabase.bind(this);
            testSuites[suite].beforeEach(async function () {
                await boundResetDatabase();
            });
            testSuite.addSuite(testSuites[suite]);
        }
        return testSuite;
    }
}
//# sourceMappingURL=abstractRepository.spec.js.map