import assert, { fail } from 'assert';
import Mocha from 'mocha';
import { UninitializedRepositoryError } from '../../errors.js';
export function testSuiteSave(repositoryTestData) {
    const testSuite = new Mocha.Suite('save');
    for (const key in repositoryTestData.entityData) {
        testSuite.addTest(new Mocha.Test(`should save a valid model (${key})`, async function () {
            const model = (await repositoryTestData.repository.create(repositoryTestData.entityData[key].request));
            assert(repositoryTestData.validateCreate(model, repositoryTestData.entityData[key].request));
            const savedModel = (await repositoryTestData.repository.save(model));
            assert(repositoryTestData.compareModels(model, savedModel));
        }));
    }
    testSuite.addTest(new Mocha.Test('should throw an UninitializedRepositoryError if the repository has not been initialized', async function () {
        for (const key in repositoryTestData.entityData) {
            const unitializedRepository = new repositoryTestData.RepositoryClass();
            try {
                await unitializedRepository.save(repositoryTestData.entityData[key].model);
                fail();
            }
            catch (error) {
                assert(error instanceof UninitializedRepositoryError);
            }
        }
    }));
    return testSuite;
}
//# sourceMappingURL=save.spec.js.map