export declare abstract class ErrorWithStatus extends Error {
    status: number;
    innerError?: Error;
    constructor(message: string, status: number, innerError?: Error);
}
export declare class HttpError extends ErrorWithStatus {
    constructor(status: number, message: string, innerError?: Error);
}
export declare class InternalServerError extends ErrorWithStatus {
    constructor(message: string, innerError?: Error);
}
export declare class ForbiddenError extends ErrorWithStatus {
    constructor(message?: string);
}
export declare class UnauthorizedError extends ErrorWithStatus {
    constructor(message?: string);
}
/**
 * This error class should be used if an entity is not found in the database.
 */
export declare class MissingEntityError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if an object is missing a needed property.
 */
export declare class MissingPropertyError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if a device is not related to a peerconnection.
 */
export declare class UnrelatedPeerconnectionError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if an operation is forbidden for the user.
 */
export declare class ForbiddenOperationError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if an operation is impossible.
 */
export declare class ImpossibleOperationError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if an object contains an invalid value.
 */
export declare class InvalidValueError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if there is an inconsistency in the database.
 */
export declare class InconsistentDatabaseError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if the user attempts an invalid change.
 */
export declare class InvalidChangeError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if a required device is not connection.
 */
export declare class DeviceNotConnectedError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if an error occurs during JWT verification.
 */
export declare class JWTVerificationError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if the body of a request is malformed.
 */
export declare class MalformedBodyError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if a parameter of a request is missing.
 */
export declare class MissingParameterError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used if a parameter of a request is malformed.
 */
export declare class MalformedParameterError extends ErrorWithStatus {
    constructor(message: string, status: number);
}
/**
 * This error class should be used when a repository has not been initialized before use.
 */
export declare class UninitializedRepositoryError extends ErrorWithStatus {
    constructor(message: string);
}
/**
 * This error class should be used when an user is not the owner of a device.
 */
export declare class DeviceOwnershipError extends ErrorWithStatus {
    constructor();
}
export declare class ValidationError extends ErrorWithStatus {
    errors: any;
    constructor(message: string, status: number, errors?: any);
}
//# sourceMappingURL=errors.d.ts.map